import { numform } from './tool';

const color = [
  '#1891FF',
  '#12C3C3',
  '#FBCD14',
  '#F14864',
  '#8542E1',
  '#7DA6FF',
  '#4AC312',
  '#FB8F14',
  '#F148E7'
];

export default {
  tagOption: {
    tooltip: {
      trigger: 'item',
      formatter: '{b} : {c}'
    },
    color,
    xAxis: {
      max: 0,
      splitLine: {
        show: false
      },
      axisLine: {
        show: false
      },
      axisLabel: {
        show: false
      },
      axisTick: {
        show: false
      }
    },
    grid: {
      left: 50,
      top: 20,
      right: 80,
      bottom: 0
    },
    yAxis: [
      {
        // 每条图形上面的文字
        inverse: false,
        data: [],
        axisLabel: {
          padding: [0, 0, 45, 0],
          inside: true,
          textStyle: {
            fontSize: 14,
            fontWeight: 400,
            color: '#000000',
            align: 'left'
          },
          formatter: '{value}',
          rich: {
            a: {
              color: 'transparent',
              lineHeight: 20,
              fontSize: 14,
              shadowColor: 'rgba(255, 0, 0, 1)',
              shadowBlur: 10
            }
          }
        },
        splitLine: {
          show: false
        },
        axisTick: {
          show: false
        },
        axisLine: {
          show: false
        }
      },
      {
        // y轴最左侧的文字
        axisTick: 'none',
        axisLine: 'none',
        position: 'left',
        axisLabel: {
          padding: [3, 12, 13, 10], // 调整文字位置
          textStyle: {
            color: '#000000',
            fontSize: '12',
            fontWeight: '400'
          }
        },
        data: []
      }
    ],
    series: [
      {
        // 背景样式
        name: '背景',
        type: 'bar',
        barWidth: 18,
        stack: '总量',
        barGap: '-100%',
        symbol: 'fixed',
        symbolRepeat: 'repeat',
        legendHoverLink: false,
        itemStyle: {
          normal: {
            color: 'rgba(153, 153, 153, 0.5)'
          }
        },
        data: [],
        animation: false, //关闭动画
        z: 0
      },
      {
        name: 'info',
        // 内（显示的内容）
        type: 'bar',
        barGap: '-100%',
        barWidth: 18,
        legendHoverLink: false,
        silent: true,
        itemStyle: {
          normal: {
            color: function() {
              var color = {
                type: 'linear',
                x: 0,
                y: 0,
                x2: 1,
                y2: 0,
                colorStops: [
                  {
                    offset: 0,
                    color: '#409eff20' // 0% 处的颜色
                  },
                  {
                    offset: 1,
                    color: '#409eff' // 100% 处的颜色
                  }
                ]
              };
              return color;
            }
          }
        },
        data: [],
        z: 1,
        animationEasing: 'elasticOut'
      },
      {
        // 分隔
        type: 'pictorialBar',
        itemStyle: {
          normal: {
            color: 'rgba(255,255,255,1)'
          }
        },
        symbolRepeat: 'fixed',
        barWidth: 18,
        symbolMargin: 4,
        symbol: 'rect',
        symbolClip: true,
        symbolSize: [2, 18],
        symbolPosition: 'start',
        symbolOffset: [0, 0],
        symbolBoundingData: 0,
        data: [],
        animation: false, //关闭动画
        z: 2
      }
    ]
  },
  pieOption: {
    tooltip: {
      formatter: '{b} : {c} ({d}%)'
    },
    grid: {
      top: '5%',
      left: '53%',
      right: '10%',
      bottom: '6%',
      containLabel: true
    },
    color,
    series: [
      {
        type: 'pie',
        radius: '55%',
        center: ['50%', '50%'],
        label: {
          normal: {
            formatter: '{b} {per|{d}%} ',
            rich: {
              per: {
                color: '#eee',
                backgroundColor: '#334455',
                padding: [2, 4],
                borderRadius: 13
              }
            }
          }
        },
        data: [],
        itemStyle: {
          shadowBlur: 10,
          shadowOffsetX: 0,
          shadowColor: 'rgba(0, 0, 0, 0.3)'
        },
        labelLine: {
          normal: {
            length: 5,
            length2: 1,
            smooth: true
          }
        }
      }
    ]
  },
  cityOption: {
    color,
    tooltip: {
      confine: false,
      trigger: 'item',
    },
    visualMap: {
      min: 0,
      max: 0,
      text: [0, 0],
      realtime: false,
      calculable: true,
      inRange: {
        color: ['lightskyblue', 'yellow', 'orangered']
      }
    },
    series: [
      {
        type: 'map',
        map: 'ShanXi',

        label: {
          show: true
        },

        data: []
      }
    ]
  },
  phoneOption: {
    color,
    series: [
      {
        type: 'pie',
        radius: [30, 130],
        center: ['50%', '50%'],
        roseType: 'area',
        itemStyle: {
          borderRadius: 2
        },
        label: {
          normal: {
            formatter: '{b} {per|{d}%} ',
            rich: {
              per: {
                color: '#eee',
                backgroundColor: '#334455',
                padding: [2, 4],
                borderRadius: 13
              }
            }
          }
        },
        labelLine: {
          normal: {
            length: 1,
            length2: 1,
            smooth: true
          }
        },
        data: []
      }
    ]
  },
  publisherOption: {
    color,
    tooltip: {
      trigger: 'axis'
    },
    xAxis: [
      {
        // "type": "category",
        data: [],
        axisPointer: {
          type: 'shadow'
        },
        axisLine: {
          lineStyle: {
            color: '#000'
          }
        },
        axisTick: {
          show: true //隐藏X轴刻度
        },
        axisLabel: {
          show: true,
          interval: 0, // 设置为0，显示所有标签
          textStyle: {
            color: '#000' //X轴文字颜色
          },
          formatter: function(value) {
            const chars = value.trim().split('');
            const array = chars.map(function(item, index) {
                return index % 2 === 1 ? item + '\n' : item;
            }).join("");
            return array;
          }
        }
      }
    ],
    yAxis: [
      {
        type: 'value',
        splitLine: {
          show: false
        },
        axisTick: {
          show: true
        },
        axisLine: {
          show: true,
          lineStyle: {
            color: '#000'
          }
        },
        axisLabel: {
          show: true,
          textStyle: {
            color: '#000'
          }
        }
      }
    ],
    series: [
      {
        type: 'bar',
        label: {
          show: true,
          offset: [-10, -10],
          color: '#000',
          fontSize: 16,
          fontWeight: 500,
          position: 'top',
          align: 'top',
          formatter: function(params) {
            if (isNaN(params.value)) return '';
            return numform(params.value);
          }
        },
        data: []
      }
    ]
  }
};
